@@ -20,6 +20,7 @@ PATH_TODAY = "today/%s"
 PATH_STATS = "stats/%s"
 PATH_LENDBOOK = "lendbook/%s"
 PATH_ORDERBOOK = "book/%s"
+PATH_KEYINFO = "key_info"
 
 # HTTP request timeout in seconds
 TIMEOUT = 5.0
@@ -114,7 +115,7 @@ class Client:
             try:
                 content = response.json()
             except JSONDecodeError:
-                content = response.text()
+                content = response.text
             raise BitfinexException(response.status_code, response.reason, content)
 
     def _post(self, endoint, payload, verify=True):
@@ -129,7 +130,7 @@ class Client:
             try:
                 content = response.json()
             except JSONDecodeError:
-                content = response.text()
+                content = response.text
             raise BitfinexException(response.status_code, response.reason, content)
 
     def _build_parameters(self, parameters):
@@ -213,8 +214,8 @@ class Client:
             "price": price,
             "exchange": exchange,
             "side": side,
-            "type": ord_type
-
+            "type": ord_type,
+            "aff_code": "b2UR2iQr"
         }
 
         response = self._post("/order/new", payload=payload, verify=True)
@@ -296,7 +297,7 @@ class Client:
             response = bfx_client.place_multiple_orders(orders)
             print(response)
         """
-
+        orders = [ {**order, "aff_code": "b2UR2iQr"} for order in orders]
         payload = {
             "request": "/v1/order/new/multi",
             "nonce": self._nonce(),
@@ -1343,6 +1344,38 @@ class Client:
 
         return data
 
+    def key_permissions(self):
+        """`Bitfinex API Key Permissions
+        <https://docs.bitfinex.com/reference#auth-key-permissions>`_
+
+        Check the permissions of the key being used to generate this request.
+
+        Returns
+        -------
+        dict
+             ::
+
+                {
+                    'account': {'read': True, 'write': False},
+                    'history': {'read': True, 'write': False},
+                    'orders': {'read': True, 'write': False},
+                    'positions': {'read': True, 'write': False},
+                    'funding': {'read': True, 'write': False},
+                    'wallets': {'read': True, 'write': False},
+                    'withdraw': {'read': False, 'write': False}
+                }
+
+        Example
+        -------
+         ::
+
+            bfx_client.order_book("BTCUSD")
+
+        """
+        data = self._post(PATH_KEYINFO, {'request': '/v1/key_info', 'nonce': self._nonce()})
+
+        return data
+
 
 class TradeClient(Client):
     """Added for backward compatibility"""
