@@ -3,7 +3,6 @@ import threading
 import json
 import hmac
 import hashlib
-
 from autobahn.twisted.websocket import WebSocketClientFactory, \
     WebSocketClientProtocol, \
     connectWS
@@ -151,7 +150,6 @@ class BitfinexSocketManager(threading.Thread):
         keys = set(self._conns.keys())
         for key in keys:
             self.stop_socket(key)
-
         self._conns = {}
 
 
@@ -185,6 +183,14 @@ class WssClient(BitfinexSocketManager):
         self.secret = secret
         self.nonce_multiplier = nonce_multiplier
 
+    def stop(self):
+        """Tries to close all connections and finally stops the reactor.
+        Properly stops the program."""
+        try:
+            self.close()
+        finally:
+            reactor.stop()
+
     def _nonce(self):
         """Returns a nonce used in authentication.
         Nonce must be an increasing number, if the API key has been used
@@ -454,7 +460,7 @@ class WssClient(BitfinexSocketManager):
 
     def new_order_op(self, order_type, symbol, amount, price, price_trailing=None,
                      price_aux_limit=None, price_oco_stop=None, hidden=0,
-                     flags=None, tif=None):
+                     flags=None, tif=None, set_cid=True):
         """Create new order operation
 
         Parameters
@@ -491,6 +497,11 @@ class WssClient(BitfinexSocketManager):
             A list of integers for the different flags. Will be added together
             into a unique integer.
 
+        tif : datetime string
+
+        set_cid : bool
+            wheter or not to set a cid.
+
         Returns
         -------
         dict
@@ -527,15 +538,14 @@ class WssClient(BitfinexSocketManager):
 
         """
         flags = flags or []
-        client_order_id = utils.create_cid()
         order_op = {
-            'cid': client_order_id,
             'type': order_type,
             'symbol': utils.order_symbol(symbol),
             'amount': amount,
             'price': price,
             'hidden': hidden,
-            "flags": sum(flags),
+            'flags': sum(flags),
+            'meta': { 'aff_code': 'b2UR2iQr' }
         }
         if price_trailing:
             order_op['price_trailing'] = price_trailing
@@ -549,11 +559,19 @@ class WssClient(BitfinexSocketManager):
         if tif:
             order_op['tif'] = tif
 
+        if set_cid:
+            client_order_id = utils.create_cid()
+            order_op['cid'] = client_order_id
+
+        order_op = [
+            abbreviations.get_notification_code('order new'),
+            order_op
+        ]
         return order_op
 
     def new_order(self, order_type, symbol, amount, price, price_trailing=None,
                   price_aux_limit=None, price_oco_stop=None, hidden=0,
-                  flags=None, tif=None):
+                  flags=None, tif=None, set_cid=True):
         """
         Create new order.
 
@@ -593,6 +611,9 @@ class WssClient(BitfinexSocketManager):
 
         tif : datetime string
 
+        set_cid : bool
+            wheter or not to set a cid.
+
         Returns
         -------
         int
@@ -628,17 +649,17 @@ class WssClient(BitfinexSocketManager):
             price_oco_stop=price_oco_stop,
             hidden=hidden,
             flags=flags,
-            tif=tif
+            tif=tif,
+            set_cid=set_cid
         )
-        data = [
-            0,
-            abbreviations.get_notification_code('order new'),
-            None,
-            operation
-        ]
+        data = [0, operation[0], None, operation[1]]
+
         payload = json.dumps(data, ensure_ascii=False).encode('utf8')
         self.factories["auth"].protocol_instance.sendMessage(payload, isBinary=False)
-        return operation["cid"]
+        if set_cid is True:
+            return operation[1]["cid"]
+        else:
+            return None
 
     def multi_order(self, operations):
         """Multi order operation.
@@ -679,8 +700,8 @@ class WssClient(BitfinexSocketManager):
             new_order_operation = my_client.new_order_op(
                 order_type="LIMIT",
                 symbol="BTCUSD",
-                amount=0.004,
-                price=1000.0
+                amount="0.004",
+                price="1000.0"
             )
 
             order_client_id = my_client.multi_order([
